@@ -1,10 +1,10 @@
 from abc import abstractmethod
-from typing import Any, Protocol
+from typing import Any, List, Protocol
 
 
 class ISubscriber(Protocol):
     @abstractmethod
-    async def init_subscriber(self):
+    async def init_subscriber(self, events: List[str]):
         raise NotImplementedError
 
     @abstractmethod
@@ -18,4 +18,3 @@ class ISubscriber(Protocol):
     @abstractmethod
     async def handle_message(self, event: str, event_data: Any):
         raise NotImplementedError
-        
